==> chaosmesh-model-5.0.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosSpecBuilder extends PodNetworkChaosSpecFluentImpl<PodNetworkChaosSpecBuilder> implements VisitableBuilder<PodNetworkChaosSpec,PodNetworkChaosSpecBuilder> {

    PodNetworkChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosSpecBuilder() {
        this(true);
    }

    public PodNetworkChaosSpecBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaosSpec(), validationEnabled);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaosSpec(), validationEnabled);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,PodNetworkChaosSpec instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,PodNetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withIpsets(instance.getIpsets()); 
        fluent.withIptables(instance.getIptables()); 
        fluent.withTcs(instance.getTcs()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpec instance) {
        this(instance,true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withIpsets(instance.getIpsets()); 
        this.withIptables(instance.getIptables()); 
        this.withTcs(instance.getTcs()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaosSpec build() {
        EditablePodNetworkChaosSpec buildable = new EditablePodNetworkChaosSpec(fluent.getIpsets(),fluent.getIptables(),fluent.getTcs());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosSpecBuilder that = (PodNetworkChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosSpecBuilder extends PodNetworkChaosSpecFluentImpl<PodNetworkChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<PodNetworkChaosSpec,PodNetworkChaosSpecBuilder> {

    PodNetworkChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosSpecBuilder() {
        this(true);
    }

    public PodNetworkChaosSpecBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaosSpec(), validationEnabled);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaosSpec(), validationEnabled);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,PodNetworkChaosSpec instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpecFluent<?> fluent,PodNetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withIpsets(instance.getIpsets()); 
        fluent.withIptables(instance.getIptables()); 
        fluent.withTcs(instance.getTcs()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpec instance) {
        this(instance,true);
    }

    public PodNetworkChaosSpecBuilder(PodNetworkChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withIpsets(instance.getIpsets()); 
        this.withIptables(instance.getIptables()); 
        this.withTcs(instance.getTcs()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaosSpec build() {
        EditablePodNetworkChaosSpec buildable = new EditablePodNetworkChaosSpec(fluent.getIpsets(),fluent.getIptables(),fluent.getTcs());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosSpecBuilder that = (PodNetworkChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
